@@ -101,16 +101,16 @@ class CompositionRestrictions:
   Restrictions for compositions when calculating permutations.
   
   ``max_consecutive_characters`` is the max consecutive same characters allowed.
-  ``prohibitted_substrings`` is the set of substrings that can't appear in the password.
+  ``prohibited_substrings`` is the set of substrings that can't appear in the password.
   ``charsets_max_consecutive`` is the list of max_consecutive characters for each charset.
   ``charsets_required_locations`` is the list of required_locations characters for each charset.
-  ``charsets_prohibitted_locations`` is the list of prohibitted_locations characters for each charset.
+  ``charsets_prohibited_locations`` is the list of prohibited_locations characters for each charset.
   """
   max_consecutive: Optional[int] = None
-  prohibitted_substrings: Optional[set[ProhibittedSubstring]] = None
+  prohibited_substrings: Optional[set[prohibitedSubstring]] = None
   charsets_max_consecutive: Optional[list[Optional[int]]] = None
   charsets_required_locations: Optional[list[Optional[set[int]]]] = None
-  charsets_prohibitted_locations: Optional[list[Optional[set[int]]]] = None
+  charsets_prohibited_locations: Optional[list[Optional[set[int]]]] = None
 
   @staticmethod
   def merge(lhs: CompositionRestrictions, rhs: CompositionRestrictions) -> CompositionRestrictions:
@@ -137,11 +137,11 @@ class CompositionRestrictions:
     elif not rhs.max_consecutive is None:
       max_consecutive = max(lhs.max_consecutive, rhs.max_consecutive)
       
-    # Use prohibitted strings that are in both sets
-    if lhs.prohibitted_substrings is None:
-      prohibitted_substrings = rhs.prohibitted_substrings
-    elif rhs.prohibitted_substrings is not None:
-      prohibitted_substrings = lhs.prohibitted_substrings | rhs.prohibitted_substrings
+    # Use prohibited strings that are in both sets
+    if lhs.prohibited_substrings is None:
+      prohibited_substrings = rhs.prohibited_substrings
+    elif rhs.prohibited_substrings is not None:
+      prohibited_substrings = lhs.prohibited_substrings | rhs.prohibited_substrings
     
     # Use the larger of the two charset consecutive character counts
     if lhs.charsets_max_consecutive is None:
@@ -160,31 +160,31 @@ class CompositionRestrictions:
         for lhs, rhs in zip(lhs.charsets_required_locations, rhs.charsets_required_locations)
       ]
       
-    # Use the intersection of the prohibitted locations
-    if lhs.charsets_prohibitted_locations is None:
-      charsets_prohibitted_locations = rhs.charsets_prohibitted_locations
-    elif rhs.charsets_prohibitted_locations is not None:
-      charsets_prohibitted_locations = [
+    # Use the intersection of the prohibited locations
+    if lhs.charsets_prohibited_locations is None:
+      charsets_prohibited_locations = rhs.charsets_prohibited_locations
+    elif rhs.charsets_prohibited_locations is not None:
+      charsets_prohibited_locations = [
         _apply(set.intersection, lhs, rhs)
-        for lhs, rhs in zip(lhs.charsets_prohibitted_locations, rhs.charsets_prohibitted_locations)
+        for lhs, rhs in zip(lhs.charsets_prohibited_locations, rhs.charsets_prohibited_locations)
       ]
       
-    return CompositionRestrictions(max_consecutive, prohibitted_substrings,
-                                   charsets_max_consecutive, charsets_required_locations, charsets_prohibitted_locations)
+    return CompositionRestrictions(max_consecutive, prohibited_substrings,
+                                   charsets_max_consecutive, charsets_required_locations, charsets_prohibited_locations)
   
   
   def __hash__(self):
     return hash(self.max_consecutive) ^ \
-      hash(tuple(self.prohibitted_substrings or [])) ^ \
+      hash(tuple(self.prohibited_substrings or [])) ^ \
       hash(tuple(self.charsets_max_consecutive or [])) ^ \
       hash(tuple(self.charsets_required_locations or [])) ^ \
-      hash(tuple(self.charsets_prohibitted_locations or [])) 
+      hash(tuple(self.charsets_prohibited_locations or [])) 
     
 
 @dataclass(frozen=True)
-class ProhibittedSubstring:
+class prohibitedSubstring:
   """
-  Represents a prohibitted substring. Keeps track of both the actual string (needed for de-duplication) and the charset composition of that string.
+  Represents a prohibited substring. Keeps track of both the actual string (needed for de-duplication) and the charset composition of that string.
   """
   substring: str
   composition: list[int] = field(compare=False, hash=False)
@@ -296,9 +296,9 @@ class Composition():
             search_space -= Composition(new_composition)._get_simple_search_space(new_charset_sizes)
       
           
-    # 3) Handle prohibitted_substrings. These substrings are represented by the charsets needed to represent them. If sufficient charset occurrences are available, remove them and replace with a single charset representing the prohibitted substring. Deduct the search space of this new (invalid) composition from the overall search space.
-    if restrictions.prohibitted_substrings is not None:
-      for substring in restrictions.prohibitted_substrings:
+    # 3) Handle prohibited_substrings. These substrings are represented by the charsets needed to represent them. If sufficient charset occurrences are available, remove them and replace with a single charset representing the prohibited substring. Deduct the search space of this new (invalid) composition from the overall search space.
+    if restrictions.prohibited_substrings is not None:
+      for substring in restrictions.prohibited_substrings:
         if all([available >= required for available, required in zip(self.composition, substring.composition)]):
           new_composition = [
             available - required for available, required in zip(self.composition, substring.composition)
@@ -311,14 +311,14 @@ class Composition():
           search_space -= Composition(new_composition)._get_simple_search_space(new_charset_sizes)
           
           
-    # 4) Handle prohibitted_locations. For each prohibitted location, we remove one occurrence for that charset and calculate how many combinations/permutations are possible for the other characters. We then remove this number for each possible violating character in the given position.
-    if restrictions.charsets_prohibitted_locations is not None:
+    # 4) Handle prohibited_locations. For each prohibited location, we remove one occurrence for that charset and calculate how many combinations/permutations are possible for the other characters. We then remove this number for each possible violating character in the given position.
+    if restrictions.charsets_prohibited_locations is not None:
       for i in range(0, len(self.composition)):
-        if restrictions.charsets_prohibitted_locations[i] is not None:
+        if restrictions.charsets_prohibited_locations[i] is not None:
           # If we can't violate the prohibition, we don't need to worry about it
           if self.composition[i] == 0: continue
           
-          for _ in restrictions.charsets_prohibitted_locations[i]:
+          for _ in restrictions.charsets_prohibited_locations[i]:
             new_composition = self.composition.copy()
             new_composition[i] -= 1
 
@@ -478,10 +478,6 @@ def get_generators(pcp: PCP, charset_mapping: dict[str,int]) -> dict[Composition
     else:
       _add_to_generators(CompositionGenerator(rule.min_length, required, max_allowed)) 
       
-
-    # Add the generator and associated restriction
-  print(generators)
-  
   return generators
         
 
@@ -500,11 +496,11 @@ def _get_composition_restrictions(
   Returns:
       Optional[CompositionRestrictions]: Restrictions, or ``None`` if there are none.
   """
-  # Process prohibitted substrings
-  prohibitted_substrings: Optional[set[ProhibittedSubstring]] = None
+  # Process prohibited substrings
+  prohibited_substrings: Optional[set[prohibitedSubstring]] = None
   
   if rule.prohibited_substrings is not None:
-    prohibitted_substrings = set()
+    prohibited_substrings = set()
     
     for substring in rule.prohibited_substrings:
       composition = [0] * len(charsets)
@@ -513,17 +509,17 @@ def _get_composition_restrictions(
           if char in charset:
             composition[charset_mapping[name]] += 1
             break
-      prohibitted_substrings.add(ProhibittedSubstring(substring, composition))
+      prohibited_substrings.add(prohibitedSubstring(substring, composition))
   
   # Process charset_* restrictions
   charsets_max_consecutive: Optional[list[Optional[int]]] = None
   charsets_required_locations: Optional[list[Optional[set[int]]]] = None
-  charsets_prohibitted_locations: Optional[list[Optional[set[int]]]] = None
+  charsets_prohibited_locations: Optional[list[Optional[set[int]]]] = None
   
   if rule.charset_requirements is not None:    
     charsets_max_consecutive = [None] * len(charset_mapping)
     charsets_required_locations = [None] * len(charset_mapping)
-    charsets_prohibitted_locations = [None] * len(charset_mapping)
+    charsets_prohibited_locations = [None] * len(charset_mapping)
     
     # Tracks required locations to prevent overlap 
     is_required_location = [False] * len(charset_mapping)
@@ -550,15 +546,15 @@ def _get_composition_restrictions(
             
         # Convert negative indices
         if requirements.prohibited_locations is not None:
-          charsets_prohibitted_locations[index] = set()
+          charsets_prohibited_locations[index] = set()
           for location in requirements.prohibited_locations:
             if location < 0: 
               location += rule.min_length
-            charsets_prohibitted_locations[index].add(location)
+            charsets_prohibited_locations[index].add(location)
             
         # Check to see that requirements is self consistent
-        if charsets_required_locations[index] is not None and charsets_prohibitted_locations is not None and \
-            len(charsets_required_locations[index].intersection(charsets_prohibitted_locations[index])) > 0:
+        if charsets_required_locations[index] is not None and charsets_prohibited_locations is not None and \
+            len(charsets_required_locations[index].intersection(charsets_prohibited_locations[index])) > 0:
           raise ValueError('Charset restrictions requires a character both be in and not be in the same location')
 
       # Check to see that requirements is self consistent
@@ -569,11 +565,11 @@ def _get_composition_restrictions(
       charsets_max_consecutive = None
     if not any(charsets_required_locations):
       charsets_required_locations = None
-    if not any(charsets_prohibitted_locations):
-      charsets_prohibitted_locations = None
+    if not any(charsets_prohibited_locations):
+      charsets_prohibited_locations = None
     
-  args = [rule.max_consecutive, prohibitted_substrings,
-          charsets_max_consecutive, charsets_required_locations, charsets_prohibitted_locations]
+  args = [rule.max_consecutive, prohibited_substrings,
+          charsets_max_consecutive, charsets_required_locations, charsets_prohibited_locations]
   if not any(args):
     return None
   else:
