@@ -65,6 +65,7 @@ def _uses_alphabet_charset(rules: list[PCPRule]) -> bool:
       return True
     if rule.charset_requirements is not None and 'alphabet' in rule.charset_requirements:
       return True
+  return False
 
 #endregion
 
@@ -139,14 +140,14 @@ class PCP():
     
     # Parse the rules
     rules: list[PCPRule]
-    if 'rules' not in data:
-      rules = [PCPRule._from_json_compatible_object(data)]
+    if 'rules' not in data or data['rules'] is None:
+      rules = [PCPRule._from_json(data)]
     else:
-      rules = [PCPRule._from_json_compatible_object(rule) for rule in data['rules']]
+      rules = [PCPRule._from_json(rule) for rule in data['rules']]
     
     # Parse the charsets
     charsets: dict[str, str] = ALPHABET_CHARSETS.copy() if _uses_alphabet_charset(rules) else DEFAULT_CHARSETS.copy()
-    if 'charsets' in data:
+    if 'charsets' in data and data['charsets'] is not None:
       for key, value in data['charsets'].items():
         if value is None or len(value) == 0:
           charsets.pop(key)
@@ -174,7 +175,7 @@ class PCP():
     if len(self.rules) < 1:
       raise ValueError(f'rules must contain at least one rule')
     for i in range(len(self.rules)):
-      self.rules[i]._validate(f'rules[{i}]', self.charsets)
+      self.rules[i]._validate(f'rules[{i}]', set(self.charsets.keys()))
       
     # TODO: Validate that min_length and max_length make sense with all the other rules.
   
@@ -208,7 +209,7 @@ class PCPRule():
   charset_requirements: Optional[dict[str,PCPCharsetRequirement]] = None
   
   @staticmethod
-  def _from_json_compatible_object(data: dict[str,Any]) -> PCPRule:
+  def _from_json(data: dict[str,Any]) -> PCPRule:
     """
     Load a PCPRule from a json-compatible object.
 
@@ -218,15 +219,15 @@ class PCPRule():
     Returns:
         PCPRule: Parsed PCPRule.
     """
-    if 'prohibited_substrings' in data:
+    if 'prohibited_substrings' in data and data['prohibited_substrings'] is not None:
       data['prohibited_substrings'] = set(data['prohibited_substrings'])
-    if 'require' in data:
+    if 'require' in data and data['require'] is not None:
       data['require'] = set(data['require'])
-    if 'require_subset' in data:
-      data['require_subset'] = PCPSubsetRequirement._from_json_compatible_object(data['require_subset'])
-    if 'charset_requirements' in data:
+    if 'require_subset' in data and data['require_subset'] is not None:
+      data['require_subset'] = PCPSubsetRequirement._from_json(data['require_subset'])
+    if 'charset_requirements' in data and data['charset_requirements'] is not None:
       data['charset_requirements'] = {
-        key: PCPCharsetRequirement._from_json_compatible_object(value) 
+        key: PCPCharsetRequirement._from_json(value) 
         for key, value in data['charset_requirements'].items() 
       }
     return PCPRule(**data)
@@ -267,7 +268,7 @@ class PCPRule():
     require_charsets = self.require or set()
     subset_charsets = self.require_subset.options or charsets if self.require_subset else set()
     if len(require_charsets.intersection(subset_charsets)) > 0:
-      raise ValueError(f'In {argname}, require, require_subset, and charset_requirements cannot have overlapping charset requirements ({key})') 
+      raise ValueError(f'In {argname}, require, require_subset, and charset_requirements cannot have overlapping charset requirements ({require_charsets.intersection(subset_charsets)})') 
     
     # Check that charset_requirements are all valid
     if self.charset_requirements is not None:
@@ -295,7 +296,7 @@ class PCPSubsetRequirement():
   options: Optional[set[str]] = None
   
   @staticmethod
-  def _from_json_compatible_object(data: dict[str,Any]) -> PCPSubsetRequirement:
+  def _from_json(data: dict[str,Any]) -> PCPSubsetRequirement:
     """Load a PCPSubsetRequirement from a json-compatible object.
 
     Args:
@@ -304,7 +305,7 @@ class PCPSubsetRequirement():
     Returns:
         PCPSubsetRequirement: Parsed PCPSubsetRequirement.
     """
-    if 'options' in data:
+    if 'options' in data and data['options'] is not None:
       data['options'] = set(data['options'])
     return PCPSubsetRequirement(**data)
     
@@ -354,7 +355,7 @@ class PCPCharsetRequirement():
   prohibited_locations: Optional[set[int]] = None
 
   @staticmethod
-  def _from_json_compatible_object(data: dict[str,Any]) -> PCPCharsetRequirement:
+  def _from_json(data: dict[str,Any]) -> PCPCharsetRequirement:
     """
     Load a PCPCharsetRequirement from a json-compatible object.
 
@@ -364,9 +365,9 @@ class PCPCharsetRequirement():
     Returns:
         PCPCharsetRequirement: Parsed PCPCharsetRequirement.
     """
-    if 'required_locations' in data:
+    if 'required_locations' in data and data['required_locations'] is not None:
       data['required_locations'] = set(data['required_locations'])
-    if 'prohibited_locations' in data:
+    if 'prohibited_locations' in data and data['prohibited_locations'] is not None:
       data['prohibited_locations'] = set(data['prohibited_locations'])    
     return PCPCharsetRequirement(**data)
     
